const path = require('path')

const systematicConfig = require('./config')

if (!process.env.CHROME_BIN) {
  process.env.CHROME_BIN = require('puppeteer').executablePath()
}

module.exports = function (basePath, _webpackConfig) {

  const webpackConfig = _webpackConfig || require('./webpack_get_defaults')(basePath)

  webpackConfig.entry = function () { return {} } // Reset the webpack entry point, test files are added separately by karma-webpack
  webpackConfig.externals = [] // Keep all the dependencies during the tests

  const testFiles = path.join(basePath, systematicConfig.test.file_pattern)

  const karmaConfig = {
    basePath: basePath,
    autoWatch: true, // Without this _in the config file_, plugins do not reload automatically
    browserNoActivityTimeout: 100000, // in ms, 100 seconds

    frameworks: ['jasmine', 'jasmine-matchers'],

    files: [
      testFiles,
    ],

    plugins: [
      'karma-jasmine',
      'karma-jasmine-matchers',
      'karma-jasmine-html-reporter',
      'karma-junit-reporter',
      'karma-webpack-error-reporter',
      'karma-chrome-launcher',
      'karma-sourcemap-loader',
      'karma-webpack',
    ],

    junitReporter: {
      outputFile: './reports/TEST-karma.xml',
      useBrowserName: false,
    },

    browsers: [process.env.CI ? 'ChromeWithoutSandbox' : 'ChromeHeadless'],
    customLaunchers: {
      ChromeWithoutSandbox: {
        base: 'ChromeHeadless',
        flags: ['--no-sandbox'],
      },
    },
    reporters: ['webpack-error'],

    webpack: webpackConfig,
    webpackMiddleware: {
      noInfo: true,
      stats: 'errors-only',
    },
  }

  karmaConfig.preprocessors = {}
  karmaConfig.preprocessors[testFiles] = ['webpack', 'sourcemap']

  return karmaConfig
}
